<?php
//
// Custom Post Type: Book
//
add_action( 'init', 'meanthemes_create_book_post_type' );
function meanthemes_create_book_post_type() {

	global $meanthemes_tools_options;

	if ( current_theme_supports( 'meanthemes_book_support' ) ) {

		$options = get_option( 'meanthemes_tools_settings' );

		// Set default value
		if ( ( isset( $options['meanthemes_tools_slug_book'] ) ) && ( $options['meanthemes_tools_slug_book'] ) ) {
			$slug = $options['meanthemes_tools_slug_book'];
		} else {
			$slug = __( 'book', 'meanthemes' );
		}

		register_post_type(
			'book',
			array(
				'labels'      => array(
					'name'               => _x( 'Books', 'post type general name', 'meanthemes' ),
					'singular_name'      => _x( 'Book', 'post type singular name', 'meanthemes' ),
					'add_new'            => _x( 'Add New', 'book item', 'meanthemes' ),
					'add_new_item'       => __( 'Add New Book', 'meanthemes' ),
					'edit_item'          => __( 'Edit Book', 'meanthemes' ),
					'new_item'           => __( 'New Book', 'meanthemes' ),
					'view_item'          => __( 'View Book', 'meanthemes' ),
					'search_items'       => __( 'Search Books', 'meanthemes' ),
					'not_found'          => __( 'Nothing found', 'meanthemes' ),
					'not_found_in_trash' => __( 'Nothing found in Trash', 'meanthemes' ),
					'parent_item_colon'  => '',
				),
				'public'      => true,
				'has_archive' => true,
				'menu_icon'   => 'dashicons-book',
				'rewrite'     => array( 'slug' => $slug ),
				'supports'    => array( 'title', 'editor', 'author', 'thumbnail', 'category', 'comments', 'revisions' ),
			)
		);
	}
}


// Register Book Category Taxonomy
function book_taxonomies() {

	if ( current_theme_supports( 'meanthemes_book_support' ) ) {

		$options = get_option( 'meanthemes_tools_settings' );

		// Set default value
		if ( ( isset( $options['meanthemes_tools_slug_book_category'] ) ) && ( $options['meanthemes_tools_slug_book_category'] ) ) {
			$slug = $options['meanthemes_tools_slug_book_category'];
		} else {
			$slug = __( 'book-categories', 'meanthemes' );
		}

		register_taxonomy(
			'book-categories',
			'book',
			array(
				'hierarchical' => true,
				'label'        => __( 'Book Categories', 'meanthemes' ),
				'query_var'    => true,
				'rewrite'      => array( 'slug' => $slug ),
			)
		);
	}
}
add_action( 'init', 'book_taxonomies', 0 );


// Register Book Tag Taxonomy
function book_taxonomies_tag() {

	if ( current_theme_supports( 'meanthemes_book_support' ) ) {

		$options = get_option( 'meanthemes_tools_settings' );

		// Set default value
		if ( ( isset( $options['meanthemes_tools_slug_book_tag'] ) ) && ( $options['meanthemes_tools_slug_book_tag'] ) ) {
			$slug = $options['meanthemes_tools_slug_book_tag'];
		} else {
			$slug = __( 'book-tags', 'meanthemes' );
		}

		register_taxonomy(
			'book-tags',
			'book',
			array(
				'hierarchical' => false,
				'label'        => __( 'Book Tags', 'meanthemes' ),
				'query_var'    => true,
				'rewrite'      => array( 'slug' => $slug ),
			)
		);

	}
}
add_action( 'init', 'book_taxonomies_tag', 0 );
