<?php
//
// Custom Post Type: Events
//
add_action( 'init', 'meanthemes_create_event_post_type' );
function meanthemes_create_event_post_type() {

	global $meanthemes_tools_options;

	if ( current_theme_supports( 'meanthemes_event_support' ) ) {

		$options = get_option( 'meanthemes_tools_settings' );

		// Set default value
		if ( ( isset( $options['meanthemes_tools_slug_event'] ) ) && ( $options['meanthemes_tools_slug_event'] ) ) {
			$slug = $options['meanthemes_tools_slug_event'];
		} else {
			$slug = __( 'event', 'meanthemes' );
		}

		register_post_type(
			'event',
			array(
				'labels'      => array(
					'name'               => _x( 'Events', 'post type general name', 'meanthemes' ),
					'singular_name'      => _x( 'Events', 'post type singular name', 'meanthemes' ),
					'add_new'            => _x( 'Add New', 'event item', 'meanthemes' ),
					'add_new_item'       => __( 'Add New Event', 'meanthemes' ),
					'edit_item'          => __( 'Edit Event', 'meanthemes' ),
					'new_item'           => __( 'New Event', 'meanthemes' ),
					'view_item'          => __( 'View Event', 'meanthemes' ),
					'search_items'       => __( 'Search Events', 'meanthemes' ),
					'not_found'          => __( 'Nothing found', 'meanthemes' ),
					'not_found_in_trash' => __( 'Nothing found in Trash', 'meanthemes' ),
					'parent_item_colon'  => '',
				),
				'public'      => true,
				'has_archive' => true,
				'menu_icon'   => 'dashicons-calendar',
				'rewrite'     => array( 'slug' => $slug ),
				'supports'    => array( 'title', 'editor', 'thumbnail', 'revisions' ),
			)
		);
	}
}


// Get theme name and only display the following on Youthy
$theme_name = wp_get_theme();

if ( $theme_name == 'Youthy' || $theme_name == 'Youthy Child' ) {

	// Make future posts viewable ie no 404
	if ( ! is_admin() ) {

		add_filter( 'the_posts', 'show_future_posts' );

		function show_future_posts( $posts ) {

			global $wp_query, $wpdb;

			// Check for event post type
			if ( 'event' == $wp_query->query_vars['post_type'] ) {
				$event = true;
			} else {
				$event = false;
			}

			if ( is_single() && $event && empty( $posts ) ) {
				$posts = $wpdb->get_results( $wp_query->request );

				// make sure it only affects future posts, not trashed
				if ( isset( $posts[0]->post_status ) && $posts[0]->post_status != 'future' ) {
					$posts = array();
				}
			}

			return $posts;
		}

		// Adjust pagination to include future posts just for the event post type
		add_filter( 'get_previous_post_where', 'my_add_future_posts_to_nav', 3, 99 );
		add_filter( 'get_next_post_where', 'my_add_future_posts_to_nav', 3, 99 );
		function my_add_future_posts_to_nav( $where, $in_same_term, $excluded_terms ) {

			global $wp_query;

			// Check for event post type
			if ( 'event' == $wp_query->query_vars['post_type'] ) {
				return str_replace( "p.post_status = 'publish'", "p.post_status IN ('publish', 'future')", $where );
			} else {
				return str_replace( "p.post_status = 'publish'", "p.post_status IN ('publish')", $where );
			}
		}
	}
}
