<?php
//
// Custom Post Type: Portfolio
//
add_action( 'init', 'meanthemes_create_portfolio_post_type' );
function meanthemes_create_portfolio_post_type() {

	global $meanthemes_tools_options;

	if ( current_theme_supports( 'meanthemes_portfolio_support' ) ) {

		// Use options to fill in slug
		$options = get_option( 'meanthemes_tools_settings' );

		// Set default value
		if ( ( isset( $options['meanthemes_tools_slug_portfolio'] ) ) && ( $options['meanthemes_tools_slug_portfolio'] ) ) {
			$slug = $options['meanthemes_tools_slug_portfolio'];
		} else {
			$slug = __( 'portfolio', 'meanthemes' );
		}

		$args = array(
			'labels'      => array(
				'name'               => _x( 'Portfolio Items', 'post type general name', 'meanthemes' ),
				'singular_name'      => _x( 'Portfolio Item', 'post type singular name', 'meanthemes' ),
				'add_new'            => _x( 'Add New', 'portfolio item', 'meanthemes' ),
				'add_new_item'       => __( 'Add New Portfolio Item', 'meanthemes' ),
				'edit_item'          => __( 'Edit Portfolio Item', 'meanthemes' ),
				'new_item'           => __( 'New Portfolio Item', 'meanthemes' ),
				'view_item'          => __( 'View Portfolio Item', 'meanthemes' ),
				'search_items'       => __( 'Search Portfolio', 'meanthemes' ),
				'not_found'          => __( 'Nothing found', 'meanthemes' ),
				'not_found_in_trash' => __( 'Nothing found in Trash', 'meanthemes' ),
				'parent_item_colon'  => '',
			),
			'public'      => true,
			'has_archive' => true,
			'menu_icon'   => 'dashicons-images-alt',
			'rewrite'     => array(
				'slug'       => $slug,
				'with_front' => false,
			),
			'supports'    => array( 'title', 'editor', 'author', 'thumbnail', 'category', 'custom-fields', 'revisions', 'comments' ),
		);

		if ( current_theme_supports( 'meanthemes_portfolio_editor_support' ) ) {
			$args['show_in_rest'] = true;
		}

		register_post_type( 'portfolio', $args );
	}
}


// Register Portfolio Taxonomy
function portfolio_taxonomies() {

	if ( current_theme_supports( 'meanthemes_portfolio_support' ) ) {

		// Use options to fill in slug
		$options = get_option( 'meanthemes_tools_settings' );

		// Set default value
		if ( ( isset( $options['meanthemes_tools_slug_portfolio_category'] ) ) && ( $options['meanthemes_tools_slug_portfolio_category'] ) ) {
			$slug = $options['meanthemes_tools_slug_portfolio_category'];
		} else {
			$slug = __( 'portfolio-item', 'meanthemes' );
		}

		register_taxonomy(
			'portfolio-item',
			'portfolio',
			array(
				'hierarchical' => true,
				'label'        => __( 'Portfolio Categories', 'meanthemes' ),
				'query_var'    => true,
				'rewrite'      => array( 'slug' => $slug ),
			)
		);

	}

}
add_action( 'init', 'portfolio_taxonomies', 0 );


/* #######################################################################

	Custom Meta for Gridset format

 ####################################################################### */


function gridset_init() {
	if ( current_theme_supports( 'meanthemes_portfolio_gridset_support' ) ) {
		add_meta_box(
			'gridset-meta',
			__( 'Gridset Formats', 'meanthemes' ),
			'gridset_meta_options',
			'portfolio',
			'normal',
			'high'
		);
	}
}

function gridset_meta_options() {
	if ( current_theme_supports( 'meanthemes_portfolio_gridset_support' ) ) {
		global $post;
		$custom = get_post_custom( $post->ID );

		$_gridset = '';

		if ( isset( $custom['_gridset'] ) ) {
			$_gridset = $custom['_gridset'][0];
		}
	}

	if ( current_theme_supports( 'meanthemes_portfolio_gridset_support' ) ) {

		wp_nonce_field( basename( __FILE__ ), 'gridset_nonce' );

		?>
		<div>
			<div><?php esc_html_e( "Using the gridset is easy, say you've got 5 images, you want the first row to hold 3 images, the next two rows to hold 2 images enter 322. If you want one image, two images, 1 image, 1 image you enter 1211", 'meanthemes' ); ?></div>
			<br />
			<label><strong><?php esc_html_e( 'Gridset Format:', 'meanthemes' ); ?></strong></label><br /><input name="_gridset" type="text" value="<?php echo $_gridset; ?>" class="large-text" /><br />
		</div>
		<?php

	}
}

function save_gridset_meta() {

	if ( current_theme_supports( 'meanthemes_portfolio_gridset_support' ) ) {
		global $post;

		if ( isset( $post->post_type ) && $post->post_type == 'portfolio' ) {

			/* Verify the nonce before proceeding. */
			if ( isset( $_POST['gridset_nonce'] ) || wp_verify_nonce( $_POST['gridset_nonce'], basename( __FILE__ ) ) ) {

				if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
					return $post->ID;
				} else {
					if ( isset( $post->ID ) ) {
						update_post_meta( $post->ID, '_gridset', $_POST['_gridset'] );
					}
				}
			}
		}
	}
}

add_action( 'admin_init', 'gridset_init' );
add_action( 'save_post', 'save_gridset_meta' );
