<?php

/*
	Plugin Name: MeanThemes Tools
	Plugin URI: https://www.meanthemes.com/plugins/meanthemes-tools/
	Description: Enhance your MeanThemes Themes.
	Version: 3.2.2
	Author: MeanThemes
	Author URI: https://www.meanthemes.com
*/



//
// Language Translation
//
function meanthemessocial_load_textdomain() {
	load_plugin_textdomain( 'meanthemes', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}
add_action( 'init', 'meanthemessocial_load_textdomain' );


//
// Add admin page
//
require_once 'settings/options-page.php';

//
// Add settings link
//
function meanthemes_tools_settings_link( $links ) {
	$settings_link = '<a href="options-general.php?page=meanthemes_tools">' . __( 'Settings', 'meanthemes' ) . '</a>';
	array_unshift( $links, $settings_link );
	return $links;
}

$plugin = plugin_basename( __FILE__ );
add_filter( "plugin_action_links_$plugin", 'meanthemes_tools_settings_link' );

// Add Customizer Options.
require_once 'settings/customizer.php';

// Include Custom Post Types.
require_once 'custom-post-type/portfolio.php';
require_once 'custom-post-type/book.php';
require_once 'custom-post-type/team.php';
require_once 'custom-post-type/service.php';
require_once 'custom-post-type/homepage-items.php';
require_once 'custom-post-type/testimonial.php';
require_once 'custom-post-type/slider.php';
require_once 'custom-post-type/logo.php';
require_once 'custom-post-type/event.php';
require_once 'custom-post-type/announcement.php';
require_once 'custom-post-type/client-logo.php';

if ( get_template() !== 'meanthemes-ampy' ) {
	// Include Shortcodes.
	require_once 'include/shortcodes.php';

	// Include Custom Meta.
	require_once 'include/custom-meta.php';

	// Include Widgets.
	require_once 'include/widgets.php';

	// Include Custom Fields for Authors.
	require_once 'include/author.php';

	// Include Enhancements.
	require_once 'include/enhance.php';
}

//
// Load front end scripts.
//
if ( get_template() !== 'meanthemes-ampy' ) {
	add_action( 'wp_enqueue_scripts', 'meanthemes_tools_load_css' );
}
function meanthemes_tools_load_css() {
	// Font Awesome, de-register first for any other plugin using it, then enqueue local copy
	wp_deregister_style( 'font-awesome' );
	wp_enqueue_style( 'font-awesome', plugin_dir_url( __FILE__ ) . 'assets/css/font-awesome.min.css', array(), '4.7.0', 'screen' );
}

//
// Load custom header scripts.
//
add_action( 'wp_head', 'meanthemes_tools_head_injection', 1, 1 );
function meanthemes_tools_head_injection() {
	if ( ! function_exists( 'amp_is_request' ) || ! amp_is_request() ) {
		// Analytics JS
		echo get_option( 'meanthemes_tools_header_scripts' ) . "\r\n";
	}
}

// Inline styles for faster page render
function meanthemes_fa_social_css() {
	$css_img_base = plugin_dir_url( __FILE__ ) . 'assets/img/';
	?>
<style type="text/css">
.social-fa {padding: 0 4px;vertical-align:middle;}.social-fa .fa {text-indent: 0;font-size: 14px;font-size: 1.4rem;line-height: 10px;color:#000; -o-transition: opacity 0.5s ease-in;-webkit-transition: opacity 0.5s ease-in;-moz-transition: opacity 0.5s ease-in;transition: opacity 0.5s ease-in;opacity: 0.5;filter: alpha(opacity=50);}.social-fa:hover .fa {opacity: 0.9;filter: alpha(opacity=90);}.social-fa.white .fa {color:#fff;}.social-fa .fa .i {position: absolute; left: -99999px; font-size: 0;}
a.social.snapchat { background: url(<?php echo esc_url( $css_img_base ); ?>social-snapchat-black.png) 0 0 no-repeat;}
a.social.white.snapchat { background: url(<?php echo esc_url( $css_img_base ); ?>social-snapchat-white.png) 0 0 no-repeat;}
@media only screen and (min--moz-device-pixel-ratio: 1.5),
only screen and (-o-min-device-pixel-ratio: 1.5/1),
only screen and (-webkit-min-device-pixel-ratio: 1.5),
only screen and (min-device-pixel-ratio: 1.5) {
  a.social.snapchat { background: url(<?php echo esc_url( $css_img_base ); ?>social-snapchat-black@2x.png) 0 0 no-repeat;background-size: 21px 21px;}
  a.social.white.snapchat { background: url(<?php echo esc_url( $css_img_base ); ?>social-snapchat-white@2x.png) 0 0 no-repeat;background-size: 21px 21px;}
}
</style>
<?php }
if ( get_template() !== 'meanthemes-ampy' ) {
	add_action( 'wp_head', 'meanthemes_fa_social_css' );
}



//
// Automatic Plugin Updates
//
require 'plugin-updates/plugin-update-checker.php';
$MyUpdateChecker = PucFactory::buildUpdateChecker(
	'http://update.meanthemes.com/plugin-updates/meanthemes-tools.json',
	__FILE__,
	'meanthemes-tools'
);

//
// Rewrite rules on plugin activation/deactivation
//
register_activation_hook( __FILE__, 'meanthemes_tools_activate' );
add_action( 'admin_init', 'meanthemes_tools_redirect' );

function meanthemes_tools_activate() {
	add_option( 'meanthemes_tools_do_activation_redirect', true );
}

function meanthemes_tools_redirect() {
	if ( get_option( 'meanthemes_tools_do_activation_redirect', false ) ) {
		delete_option( 'meanthemes_tools_do_activation_redirect' );
		if ( ! isset( $_GET['activate-multi'] ) ) {
			exit( wp_redirect( admin_url( 'options-general.php?page=meanthemes_tools' ) ) );
		}
	}
}

register_deactivation_hook( __FILE__, 'meanthemes_tools_deactivate' );
function meanthemes_tools_deactivate() {
	flush_rewrite_rules();
}


// Update nag for updates...
/* Display a notice that can be dismissed */

/*
add_action('admin_notices', 'update_admin_notice');

function update_admin_notice() {
	global $current_user ;
		$user_id = $current_user->ID;
		// Check that the user hasn't already clicked to ignore the message
	if ( ! get_user_meta($user_id, 'update_ignore_notice') ) {
		echo '<div class="updated settings-error notice is-dismissible"><p>';
		printf(__('<p>Thanks for using MeanThemes Tools, please visit <a href="/wp-admin/options-general.php?page=meanthemes_tools">MeanThemes Tools settings</a> to set up your permalinks for your MeanThemes custom post types.<a href="%1$s"><button type="button" class="notice-dismiss"><span class="screen-reader-text">Dismiss this notice.</span></button></a></p><p><strong>Don\'t forget... </strong>to sign up for the <a href="http://www.meanthemes.com/sign-up/" target="_blank">MeanThemes Newsletter</a> for updates on new themes, freebies and WordPress, HTML and CSS tips.</p>'), '?update_nag_ignore=0');
		echo "<p></p></div>";
	}
}

add_action('admin_init', 'update_nag_ignore');

function update_nag_ignore() {
	global $current_user;
		$user_id = $current_user->ID;
		// If user clicks to ignore the notice, add that to their user meta
		if ( isset($_GET['update_nag_ignore']) && '0' == $_GET['update_nag_ignore'] ) {
			 add_user_meta($user_id, 'update_ignore_notice', 'true', true);
	}
}

*/



add_action( 'admin_notices', 'mt_update_admin_notice_20012017' );

function mt_update_admin_notice_20012017() {
	global $current_user;
		$user_id = $current_user->ID;
		/* Check that the user hasn't already clicked to ignore the message */
	if ( ! get_user_meta( $user_id, 'mt_update_ignore_notice_20012017' ) ) {
				$mt_tools_link = get_admin_url() . 'options-general.php?page=meanthemes_tools';
		echo '<div class="updated notice"><p>';
		printf( __( '<p>Thanks for using MeanThemes Tools, please visit <a href="' . $mt_tools_link . '">MeanThemes Tools settings</a> to set up your permalinks for your MeanThemes custom post types.</p><p><strong>Don\'t forget... </strong>to sign up for the <a href="http://www.meanthemes.com/sign-up/" target="_blank">MeanThemes Newsletter</a> for updates on new themes, freebies and WordPress, HTML and CSS tips.</p><p><a href="%1$s"><strong>Dismiss this notice</strong></a></p>' ), '?mt_update_nag_ignore_20012017=0' );
		echo '</p></div>';
	}
}

add_action( 'admin_init', 'mt_update_nag_ignore_20012017' );

function mt_update_nag_ignore_20012017() {
	global $current_user;
		$user_id = $current_user->ID;
		/* If user clicks to ignore the notice, add that to their user meta */
	if ( isset( $_GET['mt_update_nag_ignore_20012017'] ) && '0' == $_GET['mt_update_nag_ignore_20012017'] ) {
		 add_user_meta( $user_id, 'mt_update_ignore_notice_20012017', 'true', true );
	}
}

/*
 * Apply MeanThemes Tools settings.
 */

$options = get_option( 'meanthemes_tools_settings' );

// Set responsive images on/off.
if ( isset( $options['meanthemes_tools_responsive_images'] ) && $options['meanthemes_tools_responsive_images'] ) {
	// Disable srcset everywhere.
	function disable_srcset( $sources ) {
		return false;
	}
	add_filter( 'wp_calculate_image_srcset', 'disable_srcset' );
}

// Separate core block assets.
if ( isset( $options['meanthemes_tools_separate_core_block_assets'] ) && $options['meanthemes_tools_separate_core_block_assets'] ) {
	add_filter( 'should_load_separate_core_block_assets', '__return_true' );
}

// Inline Google Fonts.
if ( isset( $options['meanthemes_tools_inline_google_fonts'] ) && $options['meanthemes_tools_inline_google_fonts'] ) {
	include_once 'include/font-stylesheet-inlining.php';
}

// CDN.
if ( isset( $options['meanthemes_tools_cdn'] ) && $options['meanthemes_tools_cdn'] && ! empty( $options['meanthemes_tools_cdn_domain'] ) ) {

	function mt_buffer_start() {
		ob_start( 'mt_cdn_buffer_callback' );
	}
	add_action( 'wp', 'mt_buffer_start' );
	
	function mt_buffer_end() {
		//ob_end_flush();
		if ( ob_get_contents() ) {
			ob_end_clean();
		}
	}
	add_action( 'shutdown', 'mt_buffer_end' );
	
	function mt_cdn_buffer_callback( $buffer ) {

		$site_domain = substr( site_url(), strpos( site_url(), '://' ) + 3 ); // Remove http(s)://
		$options     = get_option( 'meanthemes_tools_settings' );
		$cdn_domain  = esc_attr( trim( $options['meanthemes_tools_cdn_domain'] ) );
	
		if ( ! empty( $site_domain ) ) {
			$buffer = str_replace( $site_domain . '/wp-content/', $cdn_domain . '/wp-content/', $buffer );
			$buffer = str_replace( $site_domain . '/wp-includes/', $cdn_domain . '/wp-includes/', $buffer );
		}
	
		return $buffer;
	}
}

// Dequeue CF7 assets.
if ( isset( $options['meanthemes_tools_cf7_dequeue'] ) && $options['meanthemes_tools_cf7_dequeue'] && isset( $options['meanthemes_tools_cf7_dequeue_slugs'] ) ) {

	function mt_dequeue_cf7() {

		$options = get_option( 'meanthemes_tools_settings' );

		$slugs = preg_split( '/(\s*,*\s*)*,+(\s*,*\s*)*/', $options['meanthemes_tools_cf7_dequeue_slugs'] );

		if ( ! is_page( $slugs ) || is_singular( $slugs ) ) {
			add_filter( 'wpcf7_load_js', '__return_false' );
			add_filter( 'wpcf7_load_css', '__return_false' );
		}
	}
	add_action( 'wp', 'mt_dequeue_cf7' );
}
