<?php


// Add menu item and setting screen
add_action( 'admin_menu', 'meanthemes_tools_add_admin_menu' );
add_action( 'admin_init', 'meanthemes_tools_settings_init' );

function meanthemes_tools_add_admin_menu() {

	add_options_page( __( 'MeanThemes Tools', 'meanthemes' ), __( 'MeanThemes Tools', 'meanthemes' ), 'manage_options', 'meanthemes_tools', 'meanthemes_tools_options_page' );

}

// Render settings form
function meanthemes_tools_settings_init() {

	register_setting( 'meanthemes_tools', 'meanthemes_tools_settings' );

	add_settings_section(
		'meanthemes_tools_meanthemes_tools_section',
		__( 'What does this plugin do?', 'meanthemes' ),
		'meanthemes_tools_settings_section_callback',
		'meanthemes_tools'
	);

	// Check WordPress version.
	$version = get_bloginfo( 'version' );
	if ( $version >= 4.4 ) {
		add_settings_field(
			'meanthemes_tools_responsive_images',
			__( 'Turn Responsive Images Off', 'meanthemes' ),
			'meanthemes_tools_responsive_images_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
	}
	if ( $version >= 5.8 ) {
		add_settings_field(
			'meanthemes_tools_separate_core_block_assets',
			__( 'Separate Core Block Assets', 'meanthemes' ),
			'meanthemes_tools_separate_core_block_assets_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
	}

	add_settings_field(
		'meanthemes_tools_inline_google_fonts',
		__( 'Inline Google Fonts', 'meanthemes' ),
		'meanthemes_tools_inline_google_fonts_render',
		'meanthemes_tools',
		'meanthemes_tools_meanthemes_tools_section'
	);

	add_settings_field(
		'meanthemes_tools_cdn',
		__( 'Content Delivery Network', 'meanthemes' ),
		'meanthemes_tools_cdn_render',
		'meanthemes_tools',
		'meanthemes_tools_meanthemes_tools_section'
	);

	if ( is_plugin_active( 'contact-form-7/wp-contact-form-7.php' ) ) {
		add_settings_field(
			'meanthemes_tools_cf7_dequeue',
			__( 'Remove CF7 Assets', 'meanthemes' ),
			'meanthemes_tools_cf7_dequeue_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
	}

	if ( current_theme_supports( 'meanthemes_book_support' ) ) {
		add_settings_field(
			'meanthemes_tools_slug_book',
			__( 'Book Slug', 'meanthemes' ),
			'meanthemes_tools_slug_book_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
		add_settings_field(
			'meanthemes_tools_slug_book_category',
			__( 'Book Category Slug', 'meanthemes' ),
			'meanthemes_tools_slug_book_category_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
		add_settings_field(
			'meanthemes_tools_slug_book_tag',
			__( 'Book Tag Slug', 'meanthemes' ),
			'meanthemes_tools_slug_book_tag_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
	}

	if ( current_theme_supports( 'meanthemes_portfolio_support' ) ) {
		add_settings_field(
			'meanthemes_tools_slug_portfolio',
			__( 'Portfolio Slug', 'meanthemes' ),
			'meanthemes_tools_slug_portfolio_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
		add_settings_field(
			'meanthemes_tools_slug_portfolio_category',
			__( 'Portfolio Category Slug', 'meanthemes' ),
			'meanthemes_tools_slug_portfolio_category_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
	}

	if ( current_theme_supports( 'meanthemes_team_support' ) ) {
		add_settings_field(
			'meanthemes_tools_slug_team',
			__( 'Team Slug', 'meanthemes' ),
			'meanthemes_tools_slug_team_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
		add_settings_field(
			'meanthemes_tools_slug_team_category',
			__( 'Team Category Slug', 'meanthemes' ),
			'meanthemes_tools_slug_team_category_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
	}

	if ( current_theme_supports( 'meanthemes_service_support' ) ) {
		add_settings_field(
			'meanthemes_tools_slug_service',
			__( 'Service Slug', 'meanthemes' ),
			'meanthemes_tools_slug_service_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
		add_settings_field(
			'meanthemes_tools_slug_service_category',
			__( 'Service Category Slug', 'meanthemes' ),
			'meanthemes_tools_slug_service_category_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
	}

	if ( current_theme_supports( 'meanthemes_event_support' ) ) {
		add_settings_field(
			'meanthemes_tools_slug_event',
			__( 'Event Slug', 'meanthemes' ),
			'meanthemes_tools_slug_event_render',
			'meanthemes_tools',
			'meanthemes_tools_meanthemes_tools_section'
		);
	}

}


function meanthemes_tools_slug_book_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	if ( isset( $options['meanthemes_tools_slug_book'] ) && $options['meanthemes_tools_slug_book'] ) {
		$slug = $options['meanthemes_tools_slug_book'];
	} else {
		$slug = __( 'book', 'meanthemes' );
	}

	?>
  <input type='text' name='meanthemes_tools_settings[meanthemes_tools_slug_book]' value='<?php echo esc_attr( $slug ); ?>'>
	<?php

}

function meanthemes_tools_slug_book_category_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	if ( isset( $options['meanthemes_tools_slug_book_category'] ) && $options['meanthemes_tools_slug_book_category'] ) {
		$slug = $options['meanthemes_tools_slug_book_category'];
	} else {
		$slug = __( 'book-categories', 'meanthemes' );
	}

	?>
  <input type='text' name='meanthemes_tools_settings[meanthemes_tools_slug_book_category]' value='<?php echo esc_attr( $slug ); ?>'>
	<?php

}

function meanthemes_tools_slug_book_tag_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	if ( isset( $options['meanthemes_tools_slug_book_tag'] ) && $options['meanthemes_tools_slug_book_tag'] ) {
		$slug = $options['meanthemes_tools_slug_book_tag'];
	} else {
		$slug = __( 'book-tags', 'meanthemes' );
	}

	?>
  <input type='text' name='meanthemes_tools_settings[meanthemes_tools_slug_book_tag]' value='<?php echo esc_attr( $slug ); ?>'>
	<?php

}


function meanthemes_tools_slug_portfolio_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	if ( isset( $options['meanthemes_tools_slug_portfolio'] ) && $options['meanthemes_tools_slug_portfolio'] ) {
		$slug = $options['meanthemes_tools_slug_portfolio'];
	} else {
		$slug = __( 'portfolio', 'meanthemes' );
	}

	?>
  <input type='text' name='meanthemes_tools_settings[meanthemes_tools_slug_portfolio]' value='<?php echo esc_attr( $slug ); ?>'>
	<?php

}

function meanthemes_tools_slug_portfolio_category_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	if ( isset( $options['meanthemes_tools_slug_portfolio_category'] ) && $options['meanthemes_tools_slug_portfolio_category'] ) {
		$slug = $options['meanthemes_tools_slug_portfolio_category'];
	} else {
		$slug = __( 'portfolio-item', 'meanthemes' );
	}

	?>
  <input type='text' name='meanthemes_tools_settings[meanthemes_tools_slug_portfolio_category]' value='<?php echo esc_attr( $slug ); ?>'>
	<?php

}


function meanthemes_tools_slug_team_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	if ( isset( $options['meanthemes_tools_slug_team'] ) && $options['meanthemes_tools_slug_team'] ) {
		$slug = $options['meanthemes_tools_slug_team'];
	} else {
		$slug = __( 'team', 'meanthemes' );
	}

	?>
  <input type='text' name='meanthemes_tools_settings[meanthemes_tools_slug_team]' value='<?php echo esc_attr( $slug ); ?>'>
	<?php

}

function meanthemes_tools_slug_team_category_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	if ( isset( $options['meanthemes_tools_slug_team_category'] ) && $options['meanthemes_tools_slug_team_category'] ) {
		$slug = $options['meanthemes_tools_slug_team_category'];
	} else {
		$slug = __( 'team-categories', 'meanthemes' );
	}

	?>
  <input type='text' name='meanthemes_tools_settings[meanthemes_tools_slug_team_category]' value='<?php echo esc_attr( $slug ); ?>'>
	<?php

}



function meanthemes_tools_slug_service_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	if ( isset( $options['meanthemes_tools_slug_service'] ) && $options['meanthemes_tools_slug_service'] ) {
		$slug = $options['meanthemes_tools_slug_service'];
	} else {
		$slug = __( 'service', 'meanthemes' );
	}

	?>
  <input type='text' name='meanthemes_tools_settings[meanthemes_tools_slug_service]' value='<?php echo esc_attr( $slug ); ?>'>
	<?php

}

function meanthemes_tools_slug_service_category_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value
	if ( isset( $options['meanthemes_tools_slug_service_category'] ) && $options['meanthemes_tools_slug_service_category'] ) {
		$slug = $options['meanthemes_tools_slug_service_category'];
	} else {
		$slug = __( 'service-categories', 'meanthemes' );
	}

	?>
  <input type='text' name='meanthemes_tools_settings[meanthemes_tools_slug_service_category]' value='<?php echo esc_attr( $slug ); ?>'>
	<?php

}




function meanthemes_tools_slug_event_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	if ( isset( $options['meanthemes_tools_slug_event'] ) && $options['meanthemes_tools_slug_event'] ) {
		$slug = $options['meanthemes_tools_slug_event'];
	} else {
		$slug = __( 'event', 'meanthemes' );
	}

	?>
  <input type='text' name='meanthemes_tools_settings[meanthemes_tools_slug_event]' value='<?php echo esc_attr( $slug ); ?>'>
	<?php

}

function meanthemes_tools_responsive_images_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	$setting_value = '';
	if ( isset( $options['meanthemes_tools_responsive_images'] ) && $options['meanthemes_tools_responsive_images'] ) {
		$setting_value = $options['meanthemes_tools_responsive_images'];
	}

	echo '<label><input type="checkbox" name="meanthemes_tools_settings[meanthemes_tools_responsive_images]"';
	if ( $setting_value ) {
		echo ' checked';
	}
	echo '>';

	echo esc_html_e( 'Turn off the WordPress 4.4 Responsive image (srcset) "feature" here.', 'meanthemes' );

	echo '</label>';

}

function meanthemes_tools_separate_core_block_assets_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	$setting_value = '';
	if ( isset( $options['meanthemes_tools_separate_core_block_assets'] ) && $options['meanthemes_tools_separate_core_block_assets'] ) {
		$setting_value = $options['meanthemes_tools_separate_core_block_assets'];
	}

	echo '<label><input type="checkbox" name="meanthemes_tools_settings[meanthemes_tools_separate_core_block_assets]"';
	if ( $setting_value ) {
		echo ' checked';
	}
	echo '>';

	echo esc_html_e( 'Turn on the WordPress 5.8 separate core block assets feature.', 'meanthemes' );
	echo ' <a href="https://make.wordpress.org/core/2021/07/01/block-styles-loading-enhancements-in-wordpress-5-8/" target="_blank" style="text-decoration:none;"><span class="dashicons dashicons-info" title="Load styles only for rendered blocks in a page."></span></a>';

	echo '</label>';
}

function meanthemes_tools_inline_google_fonts_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	$setting_value = '';
	if ( ( isset( $options['meanthemes_tools_inline_google_fonts'] ) ) && ( $options['meanthemes_tools_inline_google_fonts'] ) ) {
		$setting_value = $options['meanthemes_tools_inline_google_fonts'];
	}

	echo '<label><input type="checkbox" name="meanthemes_tools_settings[meanthemes_tools_inline_google_fonts]"';
	if ( $setting_value ) {
		echo ' checked';
	}
	echo '>';

	echo esc_html_e( 'Fetch Google Font stylesheets and inline them.', 'meanthemes' );
	echo ' <span class="dashicons dashicons-info" title="This eliminates a render blocking critical resource and avoids invisible text during font loading. Note that this will only load the latest webfont format (woff2) and that the fallback font will be used for older browsers."></span>';

	echo '</label>';
}

function meanthemes_tools_cdn_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	$setting_value = '';
	if ( ( isset( $options['meanthemes_tools_cdn'] ) ) && ( $options['meanthemes_tools_cdn'] ) ) {
		$setting_value = $options['meanthemes_tools_cdn'];
	}

	echo '<label><input type="checkbox" name="meanthemes_tools_settings[meanthemes_tools_cdn]"';
	if ( $setting_value ) {
		echo ' checked';
	}
	echo '>';

	echo esc_html_e( 'Turn on the CDN using the following hostname: ', 'meanthemes' );

	echo '</label>';

	$slugs = isset( $options['meanthemes_tools_cdn_domain'] ) ? $options['meanthemes_tools_cdn_domain'] : '';
	echo '<input type="text" name="meanthemes_tools_settings[meanthemes_tools_cdn_domain]" value="' . esc_attr( $slugs ) . '" placeholder="myzone.my-cdn.net">';
	echo '<span class="dashicons dashicons-info" title="The CDN domain that you you wish to use to rewrite your links to. This must be a fully qualified domain name. Don\'t include http(s)://." style="vertical-align:middle;"></span>';
}

function meanthemes_tools_cf7_dequeue_render() {

	$options = get_option( 'meanthemes_tools_settings' );

	// Set default value.
	$setting_value = '';
	if ( ( isset( $options['meanthemes_tools_cf7_dequeue'] ) ) && ( $options['meanthemes_tools_cf7_dequeue'] ) ) {
		$setting_value = $options['meanthemes_tools_cf7_dequeue'];
	}

	echo '<label><input type="checkbox" name="meanthemes_tools_settings[meanthemes_tools_cf7_dequeue]"';
	if ( $setting_value ) {
		echo ' checked';
	}
	echo '>';

	echo esc_html_e( 'Only load Contact Form 7 assets on the following pages/posts: ', 'meanthemes' );

	echo '</label>';

	$slugs = isset( $options['meanthemes_tools_cf7_dequeue_slugs'] ) ? $options['meanthemes_tools_cf7_dequeue_slugs'] : 'contact';
	echo '<input type="text" name="meanthemes_tools_settings[meanthemes_tools_cf7_dequeue_slugs]" value="' . esc_attr( $slugs ) . '" placeholder="contact, contact-us">';
	echo '<a href="https://wordpress.com/support/permalinks-and-slugs/#identifying-slugs" target="_blank" style="text-decoration:none;"><span class="dashicons dashicons-info" title="Comma-separated list of slugs." style="vertical-align:middle;"></span></a>';
}

// Output message and options form to save
function meanthemes_tools_settings_section_callback() {

	echo __( '<p>MeanThemes tools enhances your MeanThemes theme. Most features are automated and activated by the theme you have chosen. The features will be listed in your theme documentation. However, there are a few things you have the ability to change below.<br><br>Thanks for purchasing one of our themes by the way :)</p>', 'meanthemes' );

}


function meanthemes_tools_options_page() {

	// Display save button...
	$button_on = false;

	// Check WordPress version
	$version = get_bloginfo( 'version' );
	if ( $version >= 4.4 ) {
		$button_on = true;
	}
	if ( current_theme_supports( 'meanthemes_team_support' ) || current_theme_supports( 'meanthemes_book_support' ) || current_theme_supports( 'meanthemes_portfolio_support' ) || current_theme_supports( 'meanthemes_service_support' ) || current_theme_supports( 'meanthemes_event_support' ) ) {
		$button_on = true;
	}

	?>
	<form action='options.php' method='post'>

		<h2><?php esc_html_e( 'MeanThemes Tools', 'meanthemes' ); ?></h2>

		<?php
		settings_fields( 'meanthemes_tools' );
		do_settings_sections( 'meanthemes_tools' );

		// Flush rewrite rules
		flush_rewrite_rules();

		if ( $button_on ) {

			submit_button();

		}

	?>
	</form>
	<?php

}
